<?php

namespace Drupal\user_not_role;

/**
 * Provides a wrapper around user_role_names().
 *
 * @internal
 *
 * @deprecated in user_not_role:1.0.0-alpha2 and is removed from
 *   user_not_role:1.0.0. This was used as an internal shim for testing and
 *   should not be used in custom code.
 *
 * @see https://www.drupal.org/project/user_not_role/issues/3435282
 */
trait UserRolesTrait {

  /**
   * A callback of \user_role_names().
   *
   * @var callable
   */
  protected $userRoleNames = NULL;

  /**
   * Sets an optional callback to use instead of \user_role_names().
   *
   * @param callable $func
   *   The function.
   */
  public function setUserRoleNames(callable $func): void {
    $this->userRoleNames = $func;
  }

  /**
   * Gets the user role names.
   *
   * @return string[]
   *   The user role ids.
   */
  public function getUserRoles(): array {
    if ($this->userRoleNames !== NULL && is_callable($this->userRoleNames)) {
      $callback = $this->userRoleNames;
      return $callback();
    }

    return function_exists('user_role_names')
      ? call_user_func('\user_role_names')
      : [];
  }

}
